####################################################
#### Discrimination analysis Spintherus Females ####
####################################################

rm(list=ls()); ls()  # tyding up workspace

#set your working directory to where the measurement dataset and Baur functions are stored
setwd("##Directory##")

#########################################################################
### Read file with functions
source("##Directory##/_Baur_functions.R", chdir = TRUE)

#### dataset
data <- "Spintherus_MRA.csv"
dat0 <- read.csv(data, sep = ";")
dat0 <- na.omit(dat0)
dat <- dat0
dat <- dat0[order(dat0$species_posteriori, dat0$country),]
str(dat)

#### select sex
dat <- subset(dat, sex == "female")


#### measurements
X <- dat[, c(9:42)]

#### omitting characters that show increased pattern of scatter
X <- subset(X, select=-c(clv.b, ool.l, ppd.b, tmp.l))

Y <- as.matrix(X)

#### choosing factors
species <- factor(dat$species_posteriori); code <- dat$code
species2 <- species
levels(species2) <- list("C1"="C1", "C2"="C2")
colours  <- c("C1"="#A6CEE3", "C2"="#B2DF8A")

#### LDA ratio extractor for finding the best axis for the separation of the two groups using shape data

### Spintherus C1 vs. C2
species1 <- dat$species_posteriori
levels(species1) <- list("C1" = "C1", "rest" = c("C2"))

re1.1 <- ldaRE2(Y, rd=1, species1); re1.1 # With rd you can select the statistical parameters of a certain ratio

          ##### Determination of minimum and maximum values of ratio 1 per group
            re1.1_ratio <- data.frame(re1.1$ratio1,species)
          ### Minimum of Ratio 1 per group
            with(re1.1_ratio, tapply(re1.1.ratio1, species, min))
          ### Maximum of Ratio 1 per group
            with(re1.1_ratio, tapply(re1.1.ratio1, species, max))
            
re1.2 <- ldaRE2(Y, rd=2, species1); re1.2

          ##### Determination of minimum and maximum values of ratio 2 per group
            re1.2_ratio <- data.frame(re1.2$ratio2,species)
          ### Minimum of Ratio 1 per group
            with(re1.2_ratio, tapply(re1.2.ratio2, species, min))
          ### Maximum of Ratio 1 per group
            with(re1.2_ratio, tapply(re1.2.ratio2, species, max))
            
            

#### Boxplots and significance tests for best separating ratios
ant.l <- X$ant.l; clv.l <- X$clv.b; clv.b <- X$clv.b; eye.d <- X$eye.d;	eye.h <- X$eye.h;	eye.b <- X$eye.b; fm3.l <- X$fm3.l; fm3.b <- X$fm3.b; fu3.b <- X$fu3.b; fu3.l <- X$fu3.l; fwi.b <- X$fwi.b; fwi.l <- X$fwi.l; gst.b <-X$gst.b;	gst.l <- X$gst.l; hea.b <- X$hea.b; hea.h <- X$hea.h;	hwi.b <- X$hwi.b; hwi.l <- X$hwi.l; mav.l <- X$mav.l; msc.b <- X$msc.b; msc.l <- X$msc.l; msp.l <- X$msp.l; mss.l <- X$mss.l; ool.l <- X$ool.l; pdl.b <- X$pdl.b; pdl.l <- X$pdl.l; pol.l <- X$pol.l; ppd.b <- X$ppd.b; ppd.l <- X$ppd.l; scp.l <- X$scp.l; sct.l <- X$sct.l; stv.l <- X$stv.l; tmp.l <- X$tmp.l; upf.l <- X$ upf.l # create variables

### Best ratios according LDA ratio extractor
# Best ratio according to LDA ratio extractor (Species 1 vs 2+3)
boxplot(gst.l/hwi.b~species, main="gst.l/hwi.b")
# wilcox.test(gst.l/hwi.b~species)

# Best ratio according to LDA ratio extractor (Species 2 vs 1+3)
boxplot(gst.l/hea.b~species, main="gst.l/hea.b")
# wilcox.test(gst.l/hea.b~species)

# Best ratio according to LDA ratio extractor (Species 1 vs 1+2)
boxplot(fwi.l/hea.b~species, main="fwi.b/hea.b")
# wilcox.test(fwi.l/hea.b~species)

# Best ratio according to ratio spectrum shape PC1
boxplot(gst.l/gst.b~species, main="gst.l/gst.b") 
# wilcox.test(gst.l/gst.b~species)

# Second best ratio according to ratio spectrum shape PC1
boxplot(mav.l/eye.b~species, main="mav.l/eye.b") 
# wilcox.test(mav.l/eye.b~species)s)

# Third best ratio according to ratio spectrum shape PC1
boxplot(fu3.b/stv.l~species, main="fu3.b/stv.l")
# wilcox.test(fu3.b/stv.l~species)

# Fourth best ratio according to ratio spectrum shape PC1
boxplot(hea.b/fwi.l~species, main="hea.b/fwi.l") 
# wilcox.test(hea.b/fwi.l~species)

# Fifth best ratio according to ratio spectrum shape PC1
boxplot(hwi.l/eye.d~species, main="hwi.l/eye.d") 
# wilcox.test(hwi.l/eye.d~species)

# Sixth best ratio according to ratio spectrum shape PC1
boxplot(sct.l/hwi.l~species, main="sct.l/hwi.l") 
# wilcox.test(sct.l/hwi.l~species)


#### Linear discriminant analysis (LDA) using all data (size and shape not separated)
## selecting priors according to number of groups
prior1 <- c(1,1)/2

## LDA for determination of discriminant function (DF)
lda <- lda(species ~ Y, prior=prior1)
plot(lda)

## LDA for crossvalidation, showing how many specimens are correctly classified according to DF
res1 <- lda(species ~ Y, prior=prior1, CV=TRUE)
CV.tab <- table(species,res1$class)
species.tab <- table(species)

percent.correct <- round((c(CV.tab[1,1]/sum(CV.tab[1,]), CV.tab[2,2]/sum(CV.tab[2,]))*100), 1)
cbind(CV.tab, percent.correct)


#### Multivariate analysis of variance (MANOVA) using all data (size and shape not separated)
man <- manova(Y ~ species)
summary(man)
