#################################################
#### Discrimination analysis Spintherus Males####
#################################################

rm(list=ls()); ls()  # tyding up workspace

#set your working directory to where the measurement dataset and Baur functions are stored
setwd("D:/Spintherus_analysis/Analysis_20190802/")

#########################################################################
### Read file with functions
source("D:/Spintherus_analysis/Analysis_20190802/_Baur_functions.R", chdir = TRUE)

#### dataset
data <- "Spintherus_MRA.csv"
dat0 <- read.csv(data, sep = ";")
dat0 <- na.omit(dat0)
dat <- dat0
dat <- dat0[order(dat0$species_posteriori, dat0$country),]
str(dat)

#### select sex
dat <- subset(dat, sex == "male")


#### measurements
X <- dat[, c(9:42)]

#### subsetting for males (no gaster measurements)
X <- X[, c(1:12, 15:34)]

#### omitting characters that show increased pattern of scatter
X <- subset(X, select=-c(pdl.l, ppd.b, tmp.l))

Y <- as.matrix(X)


#### choosing factors
species <- factor(dat$species_posteriori); code <- dat$code
species2 <- species
levels(species2) <- list("C1"="C1", "C2"="C2")
colours  <- c("C1"="#A6CEE3", "C2"="#B2DF8A")

#### LDA ratio extractor for finding the best axis for the separation of the two groups using shape data

### Spintherus C1 vs. C2
species1 <- dat$species_posteriori
levels(species1) <- list("C1" = "C1", "rest" = c("C2"))

re1.1 <- ldaRE2(Y, rd=1, species1); re1.1 # With rd you can select the statistical parameters of a certain ratio

        ##### Determination of minimum and maximum values of ratio 1 per group
          re1.1_ratio <- data.frame(re1.1$ratio1,species)
        ### Minimum of Ratio 1 per group
          with(re1.1_ratio, tapply(re1.1.ratio1, species, min))
        ### Maximum of Ratio 1 per group
          with(re1.1_ratio, tapply(re1.1.ratio1, species, max))

re1.2 <- ldaRE2(Y, rd=2, species1); re1.2

        ##### Determination of minimum and maximum values of ratio 2 per group
          re1.2_ratio <- data.frame(re1.2$ratio2,species)
        ### Minimum of Ratio 1 per group
          with(re1.2_ratio, tapply(re1.2.ratio2, species, min))
        ### Maximum of Ratio 1 per group
          with(re1.2_ratio, tapply(re1.2.ratio2, species, max))

#### Boxplots and significance tests for best separating ratios
ant.l <- X$ant.l; clv.l <- X$clv.b; clv.b <- X$clv.b; eye.d <- X$eye.d;	eye.h <- X$eye.h;	eye.b <- X$eye.b; fm3.l <- X$fm3.l; fm3.b <- X$fm3.b; fu3.b <- X$fu3.b; fu3.l <- X$fu3.l; fwi.b <- X$fwi.b; fwi.l <- X$fwi.l; gst.b <-X$gst.b;	gst.l <- X$gst.l; hea.b <- X$hea.b; hea.h <- X$hea.h;	hwi.b <- X$hwi.b; hwi.l <- X$hwi.l; mav.l <- X$mav.l; msc.b <- X$msc.b; msc.l <- X$msc.l; msp.l <- X$msp.l; mss.l <- X$mss.l; ool.l <- X$ool.l; pdl.b <- X$pdl.b; pdl.l <- X$pdl.l; pol.l <- X$pol.l; ppd.b <- X$ppd.b; ppd.l <- X$ppd.l; scp.l <- X$scp.l; sct.l <- X$sct.l; stv.l <- X$stv.l; tmp.l <- X$tmp.l; upf.l <- X$ upf.l # create variables

### Best ratios according LDA ratio extractor
# Best ratio according to LDA ratio extractor (Species 1 vs 2+3)
boxplot(ant.l/hea.b~species, main="ant.l/hea.b") 
# wilcox.test(ant.l/hea.b~species3)

# Best ratio according to LDA ratio extractor (Species 2 vs 1+3)
boxplot(ant.l/upf.l~species, main="ant.l/upf.l") 
# wilcox.test(ant.l/hea.b~species3)

# Best ratio according to LDA ratio extractor (Species 3 vs 1+2)
boxplot(ant.l/stv.l~species, main="ant.l/stv.l") 
# wilcox.test(ant.l/stv.l~species3)

### Best ratios according to ratio spectrum shape PC1
# Best ratio according to ratio spectrum shape PC1
boxplot(msc.l/fu3.l~species, main="msc.l/fu3.l") 
# wilcox.test(msc.l/fu3.l~species)

# Second best ratio according to ratio spectrum shape PC1
boxplot(upf.l/ant.l~species, main="upf.l/ant.l") 
# wilcox.test(upf.l/ant.l~species)

# Third best ratio according to ratio spectrum shape PC1
boxplot(eye.h/clv.l~species, main="eye.h/clv.l") 
# wilcox.test(eye.h/clv.l~species)

# Fourth best ratio according to ratio spectrum shape PC1
boxplot(msc.b/pdl.b~species, main="msc.b/pdl.b")
# wilcox.test(msc.b/pdl.b~species)

# Fifth best ratio according to ratio spectrum shape PC1
boxplot(mss.l/msp.l~species, main="mss.l/msp.l") 
# wilcox.test(mss.l/msp.l~species)

# Sixth best ratio according to ratio spectrum shape PC1
boxplot(sct.l/fu3.b~species, main="sct.l/fu3.b") 
# wilcox.test(sct.l/fu3.b~species)


#### Linear discriminant analysis (LDA) using all data (size and shape not separated)
## selecting priors according to number of groups
prior1 <- c(1,1)/2

## LDA for determination of discriminant function (DF)
lda <- lda(species ~ Y, prior=prior1)
plot(lda)

## LDA for crossvalidation, showing how many specimens are correctly classified according to DF
res1 <- lda(species ~ Y, prior=prior1, CV=TRUE)
CV.tab <- table(species,res1$class)
species.tab <- table(species)

percent.correct <- round((c(CV.tab[1,1]/sum(CV.tab[1,]), CV.tab[2,2]/sum(CV.tab[2,]))*100), 1)
cbind(CV.tab, percent.correct)


#### Multivariate analysis of variance (MANOVA) using all data (size and shape not separated)
man <- manova(Y ~ species)
summary(man)