#####################################
#### shape PCA Spintherus  males ####
#####################################

rm(list=ls()); ls()  # tyding up workspace

#set your working directory to where the measurement dataset and Baur functions are stored
setwd("D:/Spintherus_analysis/Analysis_20190802/")

#########################################################################
### Read file with functions
source("D:/Spintherus_analysis/Analysis_20190802/_Baur_functions.R", chdir = TRUE)


#### dataset
data <- "Spintherus_MRA.csv"
dat0 <- read.csv(data, sep = ";")
dat0 <- na.omit(dat0)
dat <- dat0
dat <- dat0[order(dat0$species_posteriori, dat0$country),]

#### select sex
dat <- subset(dat, sex == "male")
str(dat)

#### measurements
X <- dat[, c(9:42)]
str(X)

#### subsetting for males (no gaster measurements)
X <- X[, c(1:12, 15:34)]
str(X)

#### select columns from matrix
species <- factor(dat$species_posteriori); no <- dat$no; code <- dat$code; country <- dat$country; barcode <- dat$barcode

#### scatterplots of character against character
plot(X[,1:8], col=species)
plot(X[,9:16], col=species)
plot(X[,17:24], col=species)
plot(X[,25:32], col=species)

#### omitting characters that show increased pattern of scatter
X <- subset(X, select=-c(pdl.l, ppd.b, tmp.l))
str(X)

# select colors for graphs
shapes <- c("C1" = 17, "C2" = 19)
shapes_barcode <- c("C1" = 17, "C2" = 19, "nobc" = 8)
colours  <- c("C1"="#ebc827", "C2"="#56cb77")
colours_barcode  <- c("C1"="#ebc827", "C2"="#56cb77", "nobc" = "#727272")
breaks <- c("C1", "C2")
breaks_barcode <- c("C1", "C2", "nobc")



####################################################
#####  Figure X shape PCA
####################################################

spca <- shapePCA(X, rpc=3)

loadings <- round(spca$loadings,2); spca$components <- round(spca$components, 3);
pc1_s <- spca$components[2,1]*100; pc2_s <- spca$components[2,2]*100; pc3_s <- spca$components[2,3]*100


isosize <- as.numeric(spca$isosize)
shapePC1 <- spca$PCmatrix[,1]*1
shapePC2 <- spca$PCmatrix[,2]*1
shapePC3 <- spca$PCmatrix[,3]*1


#####################################################
#Plot Specimens with Barcode identification in groups
#####################################################

df <- data.frame(isosize, shapePC1, shapePC2, barcode, code, country)


#Plot Shape PC1 against shape PC2 with specimens colorcoded due to barcode identification
plot <- ggplot(df, aes(shapePC1, shapePC2, shape = barcode, color = barcode))
find_hull <- function(df)df[chull(df$shapePC1, df$shapePC2),]
hulls <- ddply(df, "barcode", find_hull)
plot <- plot + geom_point(size=10) + theme(aspect.ratio=1) + labs(title="")
# plot <- plot + labs(title="Shape PCA")
# plot <- plot + geom_polygon(data = hulls, aes(group=barcode), colour="gray80", fill = NA)
plot <- plot + scale_shape_manual(values=shapes_barcode, breaks=breaks_barcode)
plot <- plot + scale_colour_manual(values=colours_barcode, breaks=breaks_barcode)
plot <- plot  + xlab(paste("shape PC1 (",pc1_s,"%)", sep="")) + ylab(paste("shape PC2 (",pc2_s,"%)", sep=""))
plot <- plot + labs(colour = "OTU (Barcode ID)", shape= "OTU (Barcode ID)")
# plot <- plot + geom_text(aes(label=no),hjust=0.5, vjust=0)
plot <- plot + theme_bw()
a <- plot + theme(axis.text = element_text(size=24), axis.title.x = element_text(size=26), axis.title.y = element_text(size=26), plot.title = element_text(size=18), legend.title= element_text(size=26),legend.text = element_text(face="italic", size=26))
a

# #Plot Isosize against shape PC1 with specimens colorcoded due to barcode identification
# plot <- ggplot(df, aes(isosize, shapePC1, shape = barcode, color = barcode))
# plot <- plot + geom_point(size=2) + theme(aspect.ratio=1) + labs(title="")
# plot <- plot + geom_smooth(method=lm, se=FALSE, size=1)
# plot <- plot + labs(title="Checking effect of allometric scaling")
# plot <- plot + scale_shape_manual(values=shapes_barcode, breaks=breaks_barcode)
# plot <- plot + scale_colour_manual(values=colours_barcode, breaks=breaks_barcode)
# plot <- plot  + xlab("Isosize") + ylab(paste("Shape PC1 (",pc1_s,"%)", sep=""))
# plot <- plot + labs(colour = "OTU (Barcode)", shape= "OTU (Barcode)")
# # plot <- plot + geom_text(aes(label=code),hjust=0.5, vjust=0)
# b <- plot + theme(axis.title.x = element_text(size=16), axis.title.y = element_text(size=16), plot.title = element_text(size=18), legend.text = element_text(face="italic", size=13))
# b


#########################################################
#Plot Specimens with a postriori identification in groups
#########################################################

df <- data.frame(isosize, shapePC1, shapePC2, species, code, country)

#Plot Shape PC1 against shape PC2 with specimens colorcoded due to a posteriori identification
plot <- ggplot(df, aes(shapePC1, shapePC2, shape = species, color = species))
find_hull <- function(df)df[chull(df$shapePC1, df$shapePC2),]
hulls <- ddply(df, "species", find_hull)
plot <- plot + geom_polygon(data = hulls, aes(group=species), colour="gray80", fill = NA, size = 1.5)
plot <- plot + geom_point(size=10) + theme(aspect.ratio=1) + labs(title="")
# plot <- plot + labs(title="Shape PCA")
plot <- plot + scale_shape_manual(values=shapes, breaks=breaks)
plot <- plot + scale_colour_manual(values=colours, breaks=breaks)
plot <- plot  + xlab(paste("shape PC1 (",pc1_s,"%)", sep="")) + ylab(paste("shape PC2 (",pc2_s,"%)", sep=""))
plot <- plot + labs(colour = "OTU (a posteriori ID)", shape= "OTU (a posteriori ID)")
#plot <- plot + geom_text(aes(label=code),hjust=0.5, vjust=0)
plot <- plot + theme_bw()
a <- plot + theme(axis.text = element_text(size=24), axis.title.x = element_text(size=26), axis.title.y = element_text(size=26), plot.title = element_text(size=18), legend.title= element_text(size=26),legend.text = element_text(face="italic", size=26))
a

#Plot Isosize against shape PC1 with specimens colorcoded due to a postriori identification
plot <- ggplot(df, aes(isosize, shapePC1, shape = species, color = species))
plot <- plot + geom_point(size=10) + theme(aspect.ratio=1) + labs(title="")
plot <- plot + geom_smooth(method=lm, se=FALSE, size=2.5)
# plot <- plot + labs(title="Checking effect of allometric scaling")
plot <- plot + scale_shape_manual(values=shapes, breaks=breaks)
plot <- plot + scale_colour_manual(values=colours, breaks=breaks)
plot <- plot  + xlab("Isosize") + ylab(paste("Shape PC1 (",pc1_s,"%)", sep=""))
plot <- plot + labs(colour = "OTU (a posteriori ID)", shape= "OTU (a posteriori ID)")
#plot <- plot + geom_text(aes(label=code),hjust=0.5, vjust=0)
plot <- plot + theme_bw()
b <- plot + theme(axis.text = element_text(size=24), axis.title.x = element_text(size=26), axis.title.y = element_text(size=26), plot.title = element_text(size=18), legend.title= element_text(size=26),legend.text = element_text(face="italic", size=26))
b

#### PCA ratio spectrum
## PCA ratio spectrum for shape PC1
pcaRS(X, pc=1, labelsize=1.6, barlwd=5, nosize=1, sequence=-1, bootrep=1000, barcol="#1F78B4")
